@@ -34,7 +34,7 @@ provided by the 'metadata' field in a format useful to generate flatpaks.
 import configparser
 import os
 
-from buildstream import Element, ElementError, Scope
+from buildstream import Element
 
 
 class FlatpakImageElement(Element):
@@ -42,6 +42,8 @@ class FlatpakImageElement(Element):
     BST_MIN_VERSION = "2.0"
     BST_STRICT_REBUILD = True
     BST_VIRTUAL_DIRECTORY = True
+    BST_FORBID_RDEPENDS = True
+    BST_FORBID_SOURCES = True
 
     def configure(self, node):
         node.validate_keys(["directory", "include", "exclude", "metadata"])
@@ -61,19 +63,7 @@ class FlatpakImageElement(Element):
         self.metadata.read_dict(self.metadata_dict)
 
     def preflight(self):
-        runtime_deps = list(self.dependencies(Scope.RUN, recurse=False))
-        if runtime_deps:
-            raise ElementError(
-                "{}: Only build type dependencies supported by flatpak_image elements".format(
-                    self
-                )
-            )
-
-        sources = list(self.sources())
-        if sources:
-            raise ElementError(
-                "{}: flatpak_image elements may not have sources".format(self)
-            )
+        pass
 
     def get_unique_key(self):
         key = {}
@@ -88,7 +78,14 @@ class FlatpakImageElement(Element):
         pass
 
     def stage(self, sandbox):
-        pass
+        stagedir = os.path.join(os.sep, "buildstream", "allfiles")
+        with self.timed_activity("Staging dependencies", silent_nested=True):
+            self.stage_dependency_artifacts(
+                sandbox,
+                path=stagedir,
+                include=self.include,
+                exclude=self.exclude,
+            )
 
     def assemble(self, sandbox):
         self.stage_sources(sandbox, "input")
@@ -98,7 +95,6 @@ class FlatpakImageElement(Element):
         reldirectory = os.path.relpath(self.directory, "/")
         installdir = basedir.descend("buildstream", "install", create=True)
         filesdir = installdir.descend("files", create=True)
-        stagedir = os.path.join(os.sep, "buildstream", "allfiles")
 
         if self.metadata.has_section("Application"):
             installdir.descend("export", create=True)
@@ -110,21 +106,13 @@ class FlatpakImageElement(Element):
                     "files", *extensiondir.split(os.path.sep), create=True
                 )
 
-        with self.timed_activity("Creating flatpak image", silent_nested=True):
-            self.stage_dependency_artifacts(
-                sandbox,
-                Scope.BUILD,
-                path=stagedir,
-                include=self.include,
-                exclude=self.exclude,
-            )
-            if allfiles.exists(*reldirectory.split(os.path.sep)):
-                subdir = allfiles.descend(*reldirectory.split(os.path.sep))
-                filesdir.import_files(subdir)
-            if allfiles.exists("etc"):
-                etcdir = allfiles.descend("etc")
-                filesetcdir = filesdir.descend("etc", create=True)
-                filesetcdir.import_files(etcdir)
+        if allfiles.exists(*reldirectory.split(os.path.sep)):
+            subdir = allfiles.descend(*reldirectory.split(os.path.sep))
+            filesdir.import_files(subdir)
+        if allfiles.exists("etc"):
+            etcdir = allfiles.descend("etc")
+            filesetcdir = filesdir.descend("etc", create=True)
+            filesetcdir.import_files(etcdir)
 
         with installdir.open_file("metadata", mode="w") as m:
             self.metadata.write(m)
