@@ -158,7 +158,7 @@ OCI specific:
 ::
 
   Labels: {"a": "b"}
-  StopSignals: "SIGKILL"
+  StopSignal: "SIGKILL"
 
 Docker specific:
 
@@ -167,7 +167,7 @@ Docker specific:
   Memory: 2048
   MemorySwap: 4096
   CpuShares: 2
-  Heathcheck:
+  Healthcheck:
     Test: ["CMD", "/bin/test", "param"]
     Interval: 50000000000
     Timeout: 10000000000
@@ -219,7 +219,7 @@ import codecs
 import shutil
 from contextlib import contextmanager, ExitStack
 
-from buildstream import Element, ElementError, Scope
+from buildstream import Element, ElementError
 
 
 class blob:
@@ -281,7 +281,10 @@ class blob:
                             f.write("1.0")
                         self.legacy_config["id"] = h.hexdigest()
                         self.legacy_id = h.hexdigest()
-                        with blobdir.open_file("json", mode="w",) as f:
+                        with blobdir.open_file(
+                            "json",
+                            mode="w",
+                        ) as f:
                             json.dump(self.legacy_config, f)
                         self.descriptor = os.path.join(
                             h.hexdigest(), "layer.tar"
@@ -409,7 +412,7 @@ class OciElement(Element):
                     "CpuShares",
                     "Healthcheck",
                 ]
-                oci_config = ["Labels", "StopSignals"]
+                oci_config = ["Labels", "StopSignal"]
 
                 config.validate_keys(
                     common_config
@@ -452,16 +455,16 @@ class OciElement(Element):
                     healthcheck.validate_keys(
                         ["Test", "Interval", "Timeout", "Retries"]
                     )
-                    config["Healthcheck"] = {}
+                    config_value["Healthcheck"] = {}
                     if "Test" in healthcheck:
-                        config["Healthcheck"][
+                        config_value["Healthcheck"][
                             "Test"
                         ] = self.node_subst_sequence_vars(
                             healthcheck.get_sequence("Test")
                         )
                     for member in ["Interval", "Timeout", "Retries"]:
                         if member in healthcheck:
-                            config["Healthcheck"][member] = int(
+                            config_value["Healthcheck"][member] = int(
                                 self.node_subst_sequence_vars(
                                     healthcheck.get_scalar(member)
                                 )
@@ -524,7 +527,7 @@ class OciElement(Element):
             if root.exists("parent"):
                 root.remove("parent", recursive=True)
             parent = root.descend("parent", create=True)
-            parent_dep = self.search(Scope.BUILD, image["parent"]["element"])
+            parent_dep = self.search(image["parent"]["element"])
             if not parent_dep:
                 raise ElementError(
                     "{}: Element not in dependencies: {}".format(
@@ -532,11 +535,12 @@ class OciElement(Element):
                     )
                 )
 
-            parent_dep.stage_dependency_artifacts(
-                sandbox, Scope.RUN, path="parent"
-            )
+            parent_dep.stage_dependency_artifacts(sandbox, path="parent")
             if not parent.exists("index.json"):
-                with parent.open_file("manifest.json", mode="r",) as f:
+                with parent.open_file(
+                    "manifest.json",
+                    mode="r",
+                ) as f:
                     parent_index = json.load(f)
                 parent_image = parent_index[image["parent"]["image"]]
                 layers = parent_image["Layers"]
@@ -674,7 +678,7 @@ class OciElement(Element):
                 layers = []
                 parent_image = image["parent"]["image"]
                 for layer in parent_dep.images[parent_image]["layer"]:
-                    layer_dep = parent_dep.search(Scope.BUILD, layer)
+                    layer_dep = parent_dep.search(layer)
                     if not layer_dep:
                         raise ElementError(
                             "{}: Element not in dependencies: {}".format(
@@ -686,7 +690,7 @@ class OciElement(Element):
                     # element's dependencies, then we cannnot safely assume
                     # it is cached. Parent could be cached while its
                     # dependencies either removed or not pulled.
-                    if layer_dep != self.search(Scope.BUILD, layer):
+                    if layer_dep != self.search(layer):
                         self.warn(
                             "In order to optimize building of {}, you should add {} as build dependency".format(
                                 self.name, layer
@@ -702,7 +706,7 @@ class OciElement(Element):
                     ):
                         for layer_dep in layers:
                             layer_dep.stage_dependency_artifacts(
-                                sandbox, Scope.RUN, path="parent_checkout"
+                                sandbox, path="parent_checkout"
                             )
                         unpacked = True
 
@@ -752,10 +756,8 @@ class OciElement(Element):
 
         if "layer" in image:
             for name in image["layer"]:
-                dep = self.search(Scope.BUILD, name)
-                dep.stage_dependency_artifacts(
-                    sandbox, Scope.RUN, path="layer"
-                )
+                dep = self.search(name)
+                dep.stage_dependency_artifacts(sandbox, path="layer")
 
             layer = root.descend("layer")
             with self.timed_activity("Transforming into layer"):
